@@ -3,6 +3,8 @@
 #
 # Generated Mon May  2 14:23:33 2011 by parse_xsd.py version 0.4.
 #
+import base64
+
 from saml2.validate import valid_ipv4, MustValueError
 from saml2.validate import valid_ipv6
 from saml2.validate import ShouldValueError
@@ -23,20 +25,24 @@ XS_NAMESPACE = 'http://www.w3.org/2001/XMLSchema'
 XSI_TYPE = '{%s}type' % XSI_NAMESPACE
 XSI_NIL = '{%s}nil' % XSI_NAMESPACE
 
+NAMEID_FORMAT_UNSPECIFIED = (
+    "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified")
 NAMEID_FORMAT_EMAILADDRESS = (
     "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress")
-NAMEID_FORMAT_UNSPECIFIED1 = (
-    "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified")
-NAMEID_FORMAT_UNSPECIFIED = (
-    "urn:oasis:names:tc:SAML:2.0:nameid-format:unspecified")
-NAMEID_FORMAT_ENCRYPTED = (
-    "urn:oasis:names:tc:SAML:2.0:nameid-format:encrypted")
+NAMEID_FORMAT_X509SUBJECTNAME = (
+    "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName")
+NAMEID_FORMAT_WINDOWSDOMAINQUALIFIEDNAME = (
+    "urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName")
+NAMEID_FORMAT_KERBEROS = (
+    "urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos")
+NAMEID_FORMAT_ENTITY = (
+    "urn:oasis:names:tc:SAML:2.0:nameid-format:entity")
 NAMEID_FORMAT_PERSISTENT = (
     "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent")
 NAMEID_FORMAT_TRANSIENT = (
     "urn:oasis:names:tc:SAML:2.0:nameid-format:transient")
-NAMEID_FORMAT_ENTITY = (
-    "urn:oasis:names:tc:SAML:2.0:nameid-format:entity")
+NAMEID_FORMAT_ENCRYPTED = (
+    "urn:oasis:names:tc:SAML:2.0:nameid-format:encrypted")
 NAMEID_FORMATS_SAML2 = (
     ('NAMEID_FORMAT_EMAILADDRESS', NAMEID_FORMAT_EMAILADDRESS),
     ('NAMEID_FORMAT_ENCRYPTED', NAMEID_FORMAT_ENCRYPTED),
@@ -77,11 +83,12 @@ SCM_HOLDER_OF_KEY = "urn:oasis:names:tc:SAML:2.0:cm:holder-of-key"
 SCM_SENDER_VOUCHES = "urn:oasis:names:tc:SAML:2.0:cm:sender-vouches"
 SCM_BEARER = "urn:oasis:names:tc:SAML:2.0:cm:bearer"
 
-# -----------------------------------------------------------------------------
 XSD = "xs:"
 NS_SOAP_ENC = "http://schemas.xmlsoap.org/soap/encoding/"
 
-# -----------------------------------------------------------------------------
+
+_b64_decode_fn = getattr(base64, 'decodebytes', base64.decodestring)
+_b64_encode_fn = getattr(base64, 'encodebytes', base64.encodestring)
 
 
 def _decode_attribute_value(typ, text):
@@ -92,11 +99,9 @@ def _decode_attribute_value(typ, text):
     if typ == XSD + "float" or typ == XSD + "double":
         return str(float(text))
     if typ == XSD + "boolean":
-        return "%s" % (text == "true" or text == "True")
+        return str(text.lower() == "true")
     if typ == XSD + "base64Binary":
-        import base64
-
-        return base64.decodestring(text)
+        return _b64_decode_fn(text)
     raise ValueError("type %s not supported" % type)
 
 
@@ -120,9 +125,7 @@ def _verify_value_type(typ, val):
         else:
             raise ValueError("Faulty boolean value")
     if typ == XSD + "base64Binary":
-        import base64
-
-        return base64.decodestring(val.encode('utf-8'))
+        return _b64_decode_fn(val.encode())
 
 
 class AttributeValueBase(SamlBase):
@@ -177,7 +180,6 @@ class AttributeValueBase(SamlBase):
             except AttributeError:
                 self._extatt['xmlns:xs'] = XS_NAMESPACE
 
-
     def get_type(self):
         try:
             return self.extension_attributes[XSI_TYPE]
@@ -200,13 +202,11 @@ class AttributeValueBase(SamlBase):
     def set_text(self, val, base64encode=False):
         typ = self.get_type()
         if base64encode:
-            import base64
-
-            val = base64.encodestring(val)
+            val = _b64_encode_fn(val)
             self.set_type("xs:base64Binary")
         else:
             if isinstance(val, six.binary_type):
-                val = val.decode('utf-8')
+                val = val.decode()
             if isinstance(val, six.string_types):
                 if not typ:
                     self.set_type("xs:string")
@@ -224,7 +224,7 @@ class AttributeValueBase(SamlBase):
                         elif typ == "xs:base64Binary":
                             pass
                         else:
-                            ValueError("Type and value doesn't match")
+                            raise ValueError("Type and value doesn't match")
             elif isinstance(val, bool):
                 if val:
                     val = "true"
@@ -811,7 +811,16 @@ def base_id_from_string(xml_string):
 
 
 class NameID(NameIDType_):
-    """The urn:oasis:names:tc:SAML:2.0:assertion:NameID element """
+    """The urn:oasis:names:tc:SAML:2.0:assertion:NameID element
+
+    From the Oasis SAML2 Technical Overview:
+
+    "The <NameID> element within a <Subject> offers the ability to provide name
+     identifiers in a number of different formats. SAML's predefined formats
+     include: Email address, X.509 subject name, Windows domain qualified name,
+     Kerberos principal name, Entity identifier, Persistent identifier,
+     Transient identifier."
+     """
 
     c_tag = 'NameID'
     c_namespace = NAMESPACE
